import React, { useEffect, useState } from 'react';
import { Lumapps } from 'lumapps-sdk-js';
import {
    Chip,
    ChipGroup,
    ImageBlock,
    ImageBlockCaptionPosition,
    Notification,
    Kind,
    Size,
    Theme,
    AspectRatio,
} from '@lumx/react';

import { FormattedMessage, IntlProvider } from 'react-intl';
import {
    PredefinedErrorBoundary,
    useNotifications,
    NotificationsProvider,
} from '@lumapps-extensions-playground/common';

import messagesEn from '../translations/en.json';
import messagesFr from '../translations/fr.json';

interface ShareProps {
    value: {
        link: string,
        onClose: () => void,
        title: string,
        uid: string,
    };
    globalValue?: any;
    uuid: string;
    contentId: string;
    theme: Theme;
}

const Widget = ({
    value,
    globalValue = {},
    uuid,
    contentId,
    theme = Theme.light,
}: ShareProps): React.ReactElement => {
    const [url, setUrl] = useState<string | undefined>();
    const [error, setError] = useState<string>();

    const { link, onClose, title, uid } = value;

    useEffect(() => {
      
    }, []);

    return (
        <div>
            
        </div>
    );
};

const NotificationAwareWidget = (props: any) => {
    const messages: any = {
        en: messagesEn,
        fr: messagesFr,
    };
    const [lang, setLang] = useState<string>('en');
    useEffect(() => {
        const getContext = async () => {
            const lumapps = new Lumapps();
            const { userLang: userLangPromise } = lumapps.context;

            const userLang = await userLangPromise;
            const isLangInTrad = Object.keys(messages).includes(userLang);

            setLang(isLangInTrad ? userLang : 'en');
        };
        getContext();
    }, []);

    return (
        <IntlProvider messages={messages[lang]} locale={lang}>
            <NotificationsProvider>
                <PredefinedErrorBoundary>
                    <Widget {...props} />
                </PredefinedErrorBoundary>
            </NotificationsProvider>
        </IntlProvider>
    );
};

export { NotificationAwareWidget as Widget } ;
